CreateFeatureCommand class final

Inheritance

Constructors

CreateFeatureCommand({required Logger logger, required MasonGeneratorFromBundle? generatorFromBundle, required MasonGeneratorFromBrick? generatorFromBrick})

Properties

aliases → List<String>
Alternate names for this command.
no setterinherited
argParser → ArgParser
The argument parser for this command.
no setterinherited
argResultOverrides ↔ ArgResults?
getter/setter pairinherited
argResults → ArgResults
The parsed argument results for this command.
no setterinherited
category → String
The command's category.
no setterinherited
description → String
A description of this command, included in usage.
no setteroverride
featureName → String
no setter
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation → String
A single-line template for how to invoke this command (e.g. "pub get package").
no setteroverride
logger → Logger
finalinherited
name → String
The name of this command.
no setteroverride
outputDirectory → String?
Gets the output directory from arguments
no setterinherited
parent → Command<int>?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner<int>?
The command runner for this command.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subcommands → Map<String, Command<int>>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases → List<String>
Alternate non-functional names for this command.
no setterinherited
summary → String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments → bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
template → Template
The template to use for generation
no setteroverride
usage → String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter → String?
An optional footer for usage.
no setterinherited

Methods

addSubcommand(Command<int> command) → void
Adds Command as a subcommand of this.
inherited
getTargetDirectory() → Future<Directory>
Determines the target directory for generation
override
getTemplateVars() → Map<String, dynamic>
Gets template variables for generation
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printUsage() → void
Prints the usage information for this command.
inherited
run() → Future<int>
Runs the command
inherited
runGenerate(MasonGenerator generator, Directory targetDir) → Future<int>
Runs the generation process
inherited
setupArgParser() → void
Sets up the argument parser with command-specific options
override
toString() → String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited
validateArgs() → void
Validates command-specific arguments
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited